=======
Credits
=======

Development Lead
----------------
* `Mark van Koningsveld`_
* `Joris den Uijl`_
* `Fedor Baart`_

.. _Mark van Koningsveld: https://www.tudelft.nl/citg/over-faculteit/afdelingen/hydraulic-engineering/sections/rivers-ports-waterways-and-dredging-engineering/staff/prof-dr-ir-m-mark-van-koningsveld/
.. _Joris den Uijl: https://github.com/uijl
.. _Fedor Baart: https://github.com/SiggyF

Contributors
------------

So far the main contributions come from Joris den Uijl, Fedor Baart and Mark van Koningsveld.